@@ -1,8 +1,9 @@
-from evalgraph.nodes import Scenario, ScenarioContext, BaseScenario
+from evalgraph.scenarios import Scenario, BaseScenario
+from evalgraph.scenariocontext import ScenarioContext
 from evalgraph.option import Underlier, Option
 
 class SpotShiftScenario(Scenario):
-    def __init__(self, source, shift):
+    def __init__(self, shift, source = None):
         super().__init__(source)
         self.shift = shift
         
