@@ -1,8 +1,7 @@
 import datetime as dt, pandas as pd
 from scipy.stats import norm
 import math
-from evalgraph.nodes import node, nodefn, GraphEvaluator
-
+from evalgraph.nodes import node, nodefn
 
 class Market:
     def __repr__(self):
@@ -89,6 +88,7 @@ class Option(NodeObject):
         return x * self.Strike()
    
 if __name__ == "__main__":
+    from graphevaluator import GraphEvaluator
     GraphEvaluator.verbose = False
     und = Underlier(Ticker='SPY')
     o = Option(OptionType='C',Underlier=und,Strike=und.Spot())
